@@ -90,7 +90,6 @@ class NaverKinCrawler(BaseCrawler):
             )
 
 
-
     def kin_detail_parser(self, response, parsed, meta):
         question = dict(
             title = parsed['question_title'],
@@ -182,7 +181,9 @@ class NaverKinCrawler(BaseCrawler):
                     'uid': comment['u']
                 }
             )
-            
+    
+    def default_breaker(self, response):
+        return False
 
 
 
@@ -190,4 +191,5 @@ def test_naverkin(keywords, page_range):
     nkc = NaverKinCrawler(keywords, page_range,
         settings=settings
     )
-    return nkc.crawl()
+    nkc.crawl()
+    return nkc
